@@ -1,23 +1,25 @@
 from django.core.management.base import BaseCommand
-from django.core.management.base import CommandError
 
 from axes.utils import reset
 
 
 class Command(BaseCommand):
-    args = ''
     help = ("resets any lockouts or failed login records. If called with an "
             "IP, resets only for that IP")
 
+    def add_arguments(self, parser):
+        parser.add_argument('ip', nargs='*')
+
     def handle(self, *args, **kwargs):
         count = 0
-        if args:
-            for ip in args:
+        if kwargs and kwargs.get('ip'):
+            for ip in kwargs['ip'][1:]:
                 count += reset(ip=ip)
         else:
             count = reset()
 
-        if count:
-            print '{0} attempts removed.'.format(count)
-        else:
-            print 'No attempts found.'
+        if kwargs['verbosity']:
+            if count:
+                self.stdout.write('{0} attempts removed.'.format(count))
+            else:
+                self.stdout.write('No attempts found.')
